@@ -1,6 +1,6 @@
 from .imports import*
 
-def train_and_explainModel(model:str, tabular_data:Tabular, x_ai:list, indexList:list = [], scale:bool = True, scaleType:str = "StandardScaler", addendum:str = "", verbose:bool = False, **modelSpecificArgs): # Returns the model function and scaler (if applicable)
+def train_and_explainModel(model:str, tabular_data:Tabular, x_ai:list = [], indexList:list = [], scale:bool = True, scaleType:str = "StandardScaler", addendum:str = "", verbose:bool = False, **modelSpecificArgs): # Returns the model function and scaler (if applicable)
     ''' A function that attempts to train and explain a particular sklearn model.
     
     :param str model: Name of Model
@@ -20,7 +20,7 @@ def train_and_explainModel(model:str, tabular_data:Tabular, x_ai:list, indexList
     returnList = []
     
     try:
-      assert model in acceptedModels.keys()
+      assert model in acceptedModels.keys(), "Model is not accepted."
       exec('from ' + acceptedModels.get(model) + ' import*')
       modeler= eval(model + "( **modelSpecificArgs )") #Create model function from provided model name. This will not work if model is not part of sklearn library or is unsupervised.
     except Exception as e:
